==> cmtk_3.2.2.orig.tar.gz: cmtk-3.2.2/libs/Base/cmtkUniformVolumeInterpolatorBase.cxx <==
/*
//
//  Copyright 1997-2009 Torsten Rohlfing
//
//  Copyright 2004-2010 SRI International
//
//  This file is part of the Computational Morphometry Toolkit.
//
//  http://www.nitrc.org/projects/cmtk/
//
//  The Computational Morphometry Toolkit is free software: you can
//  redistribute it and/or modify it under the terms of the GNU General Public
//  License as published by the Free Software Foundation, either version 3 of
//  the License, or (at your option) any later version.
//
//  The Computational Morphometry Toolkit is distributed in the hope that it
//  will be useful, but WITHOUT ANY WARRANTY; without even the implied
//  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License along
//  with the Computational Morphometry Toolkit.  If not, see
//  <http://www.gnu.org/licenses/>.
//
//  $Revision: 2196 $
//
//  $LastChangedDate: 2010-08-12 11:39:37 -0700 (Thu, 12 Aug 2010) $
//
//  $LastChangedBy: torstenrohlfing $
//
*/

#include "cmtkUniformVolumeInterpolatorBase.h"

#include <limits>

void
cmtk::UniformVolumeInterpolatorBase
::SetVolume( const UniformVolume& volume )
{
  const TypedArray& data = *(volume.GetData());
  const size_t nPixels = data.GetDataSize();
  this->m_VolumeDataArray.resize( nPixels );
  for ( size_t n = 0; n < nPixels; ++n )
    {
    if ( !data.Get( this->m_VolumeDataArray[n], n ) )
      this->m_VolumeDataArray[n] = std::numeric_limits<Types::DataItem>::infinity();
    }
  
  this->m_VolumeDims = volume.GetDims();
  this->m_VolumeDeltas = volume.Deltas();
  this->m_VolumeOffset = volume.m_Offset;
  this->m_NextJ = this->m_VolumeDims[0];
  this->m_NextK = this->m_NextJ * this->m_VolumeDims[1];    
}

==> cmtk_3.3.1.orig.tar.gz: cmtk-3.3.1/libs/Base/cmtkUniformVolumeInterpolatorBase.cxx <==
/*
//
//  Copyright 2016 Google, Inc.
//
//  Copyright 1997-2009 Torsten Rohlfing
//
//  Copyright 2004-2010 SRI International
//
//  This file is part of the Computational Morphometry Toolkit.
//
//  http://www.nitrc.org/projects/cmtk/
//
//  The Computational Morphometry Toolkit is free software: you can
//  redistribute it and/or modify it under the terms of the GNU General Public
//  License as published by the Free Software Foundation, either version 3 of
//  the License, or (at your option) any later version.
//
//  The Computational Morphometry Toolkit is distributed in the hope that it
//  will be useful, but WITHOUT ANY WARRANTY; without even the implied
//  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License along
//  with the Computational Morphometry Toolkit.  If not, see
//  <http://www.gnu.org/licenses/>.
//
//  $Revision: 5398 $
//
//  $LastChangedDate: 2016-01-14 18:29:18 -0800 (Thu, 14 Jan 2016) $
//
//  $LastChangedBy: torstenrohlfing $
//
*/

#include "cmtkUniformVolumeInterpolatorBase.h"

#include <limits>

void
cmtk::UniformVolumeInterpolatorBase
::SetVolume( const UniformVolume& volume )
{
  const TypedArray& data = *(volume.GetData());
  const size_t nPixels = data.GetDataSize();
  this->m_VolumeDataArray.resize( nPixels );
  for ( Types::GridIndexType n = 0; n < nPixels; ++n )
    {
    if ( !data.Get( this->m_VolumeDataArray[n], n ) )
      this->m_VolumeDataArray[n] = std::numeric_limits<Types::DataItem>::infinity();
    }
  
  this->m_VolumeDims = volume.GetDims();
  this->m_VolumeDeltas = volume.Deltas();
  this->m_VolumeOffset = volume.m_Offset;
  this->m_NextJ = this->m_VolumeDims[0];
  this->m_NextK = this->m_NextJ * this->m_VolumeDims[1];    
}
